FunctionSampler
======================================

.. currentmodule:: imblearn

.. autoclass:: FunctionSampler

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~FunctionSampler.fit
      
      
        ~FunctionSampler.fit_resample
      
      
        ~FunctionSampler.get_feature_names_out
      
      
        ~FunctionSampler.get_metadata_routing
      
      
        ~FunctionSampler.get_params
      
      
        ~FunctionSampler.set_params
      
   
   

.. include:: imblearn.FunctionSampler.examples

.. raw:: html

    <div style='clear:both'></div>